<?php

namespace WPS\WPS_Chatbot_AI;

class Plugin {

	use Singleton;

	protected function init() {
		add_filter( 'plugin_action_links_' . WPS_CHATBOT_AI_BASENAME, array( $this, 'plugin_action_links' ) );
		add_action( 'customize_register', array( __CLASS__, 'customize_register' ), 99 );
		add_action( 'wp_enqueue_scripts', array( __CLASS__, 'admin_enqueue_scripts' ) );
		add_shortcode( 'wps_chatgpt_assistant', array( __CLASS__, 'shortcode_chatbot_wordpress' ) );
		add_action( 'wp_footer', array( __CLASS__, 'wps_chatgpt_assistant_shortcodes_show_all' ) );

		add_action( 'wp_ajax_wps_chatbot_ai_ajax_save_chat', array(
			__CLASS__,
			'wps_chatbot_ai_ajax_save_chat_action'
		) );
		add_action( 'wp_ajax_nopriv_wps_chatbot_ai_ajax_save_chat', array(
			__CLASS__,
			'wps_chatbot_ai_ajax_save_chat_action'
		) );

		add_action( 'admin_menu', array( __CLASS__, 'add_plugin_menu' ) );
	}

	/**
	 * Plugin activation
	 */
	public static function activate() {
		global $wpdb;

		$charset_collate = $wpdb->get_charset_collate();

		$chatbot_table_name = $wpdb->prefix . 'wps_chatbot_ai';
		$sql                = "CREATE TABLE IF NOT EXISTS $chatbot_table_name (
            id bigint(20) unsigned NOT NULL auto_increment,
            answer varchar(255) NOT NULL,
            response varchar(255) NOT NULL,
            ip varchar(50) NOT NULL,
            time datetime DEFAULT CURRENT_TIMESTAMP NOT NULL,
            PRIMARY KEY  (id)
        ) $charset_collate;";

		require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );

		dbDelta( $sql );
	}

	public function plugin_action_links( $links ) {
		if ( is_network_admin() && is_plugin_active_for_network( WPS_CHATBOT_AI_BASENAME ) ) {
			array_unshift( $links, '<a href="' . esc_url( add_query_arg(
					'autofocus[section]',
					'wpb_chatbot_ai_section',
					network_admin_url( 'customize.php' )
				) ) . '">' . __( 'Personalization', 'wps-ai-chatgpt' ) . '</a>' );
		} elseif ( ! is_network_admin() ) {
			array_unshift( $links, '<a href="' . esc_url( add_query_arg(
					'autofocus[section]',
					'wpb_chatbot_ai_section',
					admin_url( 'customize.php' )
				) ) . '">' . __( 'Personalization', 'wps-ai-chatgpt' ) . '</a>' );
		}

		return $links;
	}

	public static function customize_register( $wp_customize ) {
		// Personnaliser NOM +  fonction + personnalité du chatbot avec métier ou fonction (ex : Trader, cuisinier, coach de vie)
		// Personnaliser voix ou ton du chatbot

		// Voir langue chatbot

		$wp_customize->add_setting( 'wpb_chatbot_ai_widget_api_key', array(
			'transport' => 'refresh',
		) );

		$wp_customize->add_setting( 'wpb_chatbot_ai_widget_color', array(
			'default'   => '#4f46e5',
			'transport' => 'refresh',
		) );

		$wp_customize->add_setting( 'wpb_chatbot_ai_widget_background_color', array(
			'default'   => '#ffffff',
			'transport' => 'refresh',
		) );

		$wp_customize->add_setting( 'wpb_chatbot_ai_widget_darkmode', array(
			'transport' => 'refresh',
		) );

		$wp_customize->add_setting( 'wpb_chatbot_ai_widget_response_background_color', array(
			'default'   => '#d3d3d3',
			'transport' => 'refresh',
		) );

		$wp_customize->add_setting( 'wpb_chatbot_ai_widget_user_message_background_color', array(
			'default'   => '#4e426d',
			'transport' => 'refresh',
		) );

		$wp_customize->add_setting( 'wpb_chatbot_ai_widget_show_chat_front_end', array(
			'default'   => true,
			'transport' => 'refresh',
		) );

		$wp_customize->add_setting( 'wpb_chatbot_ai_widget_icon', array(
			'transport' => 'refresh',
		) );

		$wp_customize->add_section( 'wpb_chatbot_ai_section', array(
			'title'    => __( 'WPS AI ChatGPT', 'wps-ai-chatgpt' ),
			'priority' => 300,
		) );

		$wp_customize->add_setting( 'wpb_chatbot_ai_widget_temperature', array(
			'default'   => '0.8', // 0.1
			'transport' => 'refresh',
		) );

		$wp_customize->add_setting( 'wpb_chatbot_ai_widget_max_tokens', array(
			'default'   => 1500, //2000
			'transport' => 'refresh',
		) );

		$wp_customize->add_setting( 'wpb_chatbot_ai_widget_max_frequency_penalty', array(
			'default'   => '0.01', //0
			'transport' => 'refresh',
		) );

		$wp_customize->add_setting( 'wpb_chatbot_ai_widget_max_presence_penalty', array(
			'default'   => '0.01', //0.5
			'transport' => 'refresh',
		) );

		/*$wp_customize->add_setting( 'wpb_chatbot_ai_widget_bestof', array(
			'default'   => 1,
			'transport' => 'refresh',
		) );*/

		$wp_customize->add_setting( 'wpb_chatbot_ai_widget_position', array(
			'default'   => 'right',
			'transport' => 'refresh',
		) );

		$wp_customize->add_setting( 'wpb_chatbot_ai_widget_pub_top' );

		require_once WPS_CHATBOT_AI_DIR . '/classes/customize-controls.php';

		$wp_customize->add_control( new \WP_Pub_AI_Customize_Control( $wp_customize, 'wpb_chatbot_ai_widget_pub_top', array(
			'label'    => __( 'Pub top', 'wps-ai-chatgpt' ),
			'section'  => 'wpb_chatbot_ai_section',
			'settings' => 'wpb_chatbot_ai_widget_pub_top'
		) ) );

		$wp_customize->add_control( new \WP_Customize_Control( $wp_customize, 'wpb_chatbot_ai_widget_api_key', array(
			'label'       => __( 'API KEY', 'wps-ai-chatgpt' ),
			'description' => __( 'Enter your OPEN AI API key or buy token packs directly from WPServeur at the best price, without leaving your credit card as collateral.', 'wps-ai-chatgpt' ),
			'section'     => 'wpb_chatbot_ai_section',
			'settings'    => 'wpb_chatbot_ai_widget_api_key'
		) ) );

		$wp_customize->add_control( new \WP_Customize_Color_Control( $wp_customize, 'wpb_chatbot_ai_widget_color', array(
			'label'    => __( 'Color widget', 'wps-ai-chatgpt' ),
			'section'  => 'wpb_chatbot_ai_section',
			'settings' => 'wpb_chatbot_ai_widget_color',
		) ) );

		$wp_customize->add_control( new \WP_Customize_Color_Control( $wp_customize, 'wpb_chatbot_ai_widget_background_color', array(
			'label'    => __( 'Background color widget', 'wps-ai-chatgpt' ),
			'section'  => 'wpb_chatbot_ai_section',
			'settings' => 'wpb_chatbot_ai_widget_background_color',
		) ) );

		$wp_customize->add_control( new \WP_Customize_Control( $wp_customize, 'wpb_chatbot_ai_widget_darkmode', array(
			'label'    => __( 'Darkmode ?', 'wps-ai-chatgpt' ),
			'section'  => 'wpb_chatbot_ai_section',
			'settings' => 'wpb_chatbot_ai_widget_darkmode',
			'type'     => 'checkbox',
		) ) );

		$wp_customize->add_control( new \WP_Customize_Color_Control( $wp_customize, 'wpb_chatbot_ai_widget_response_background_color', array(
			'label'    => __( 'Response background color widget', 'wps-ai-chatgpt' ),
			'section'  => 'wpb_chatbot_ai_section',
			'settings' => 'wpb_chatbot_ai_widget_response_background_color',
		) ) );

		$wp_customize->add_control( new \WP_Customize_Color_Control( $wp_customize, 'wpb_chatbot_ai_widget_user_message_background_color', array(
			'label'    => __( 'User message background color widget', 'wps-ai-chatgpt' ),
			'section'  => 'wpb_chatbot_ai_section',
			'settings' => 'wpb_chatbot_ai_widget_user_message_background_color',
		) ) );

		$wp_customize->add_control( new \WP_Customize_Control( $wp_customize, 'wpb_chatbot_ai_widget_show_chat_front_end', array(
			'label'    => __( 'Show chat front end ?', 'wps-ai-chatgpt' ),
			'section'  => 'wpb_chatbot_ai_section',
			'settings' => 'wpb_chatbot_ai_widget_show_chat_front_end',
			'type'     => 'select',
			'choices'  => array(
				'true'  => __( 'Yes', 'wps-ai-chatgpt' ),
				'false' => __( 'No', 'wps-ai-chatgpt' ),
			),
		) ) );

		$wp_customize->add_control(
			new \WP_Customize_Image_Control(
				$wp_customize,
				'wpb_chatbot_ai_widget_icon',
				array(
					'label'    => __( 'Widget icon', 'wps-ai-chatgpt' ),
					'section'  => 'wpb_chatbot_ai_section',
					'settings' => 'wpb_chatbot_ai_widget_icon',
					'context'  => 'your_setting_context'
				)
			)
		);

		$wp_customize->add_setting( 'wpb_chatbot_ai_widget_function_job', array(
			'sanitize_callback' => 'sanitize_text_field',
		) );

		$wp_customize->add_control( 'wpb_chatbot_ai_widget_function_job', array(
			'label'       => __( 'Function / Job of your Chatbot', 'wps-ai-chatgpt' ),
			'section'     => 'wpb_chatbot_ai_section',
			'settings'    => 'wpb_chatbot_ai_widget_function_job',
			'type'        => 'text',
			'input_attrs' => array(
				'placeholder' => __( 'ex: Trader, cook, life coach', 'wps-ai-chatgpt' ),
			)
		) );

		$wp_customize->add_setting( 'wpb_chatbot_ai_widget_personality', array(
			'default'           => 'Personal',
			'sanitize_callback' => 'sanitize_text_field',
		) );

		$wp_customize->add_control( 'wpb_chatbot_ai_widget_personality', array(
			'label'    => __( 'Personality of your Chatbot', 'wps-ai-chatgpt' ),
			'section'  => 'wpb_chatbot_ai_section',
			'settings' => 'wpb_chatbot_ai_widget_personality',
			'type'     => 'select',
			'choices'  => array(
				'Encouraging'   => __( 'Encouraging', 'wps-ai-chatgpt' ),
				'Persuasive'    => __( 'Persuasive', 'wps-ai-chatgpt' ),
				'Thoughtful'    => __( 'Thoughtful', 'wps-ai-chatgpt' ),
				'Personal'      => __( 'Personal', 'wps-ai-chatgpt' ),
				'Witty'         => __( 'Witty', 'wps-ai-chatgpt' ),
				'Funny'         => __( 'Funny', 'wps-ai-chatgpt' ),
				'Empathetic'    => __( 'Empathetic', 'wps-ai-chatgpt' ),
				'Compassionate' => __( 'Compassionate', 'wps-ai-chatgpt' ),
			)
		) );

		$wp_customize->add_setting( 'wpb_chatbot_ai_widget_language', array(
			'default'           => 'french',
			'sanitize_callback' => 'sanitize_text_field',
		) );

		$wp_customize->add_control( 'wpb_chatbot_ai_widget_language', array(
			'label'    => __( 'Language of your Chatbot', 'wps-ai-chatgpt' ), //
			'section'  => 'wpb_chatbot_ai_section',
			'settings' => 'wpb_chatbot_ai_widget_language',
			'type'     => 'select',
			'choices'  => array(
				'french'  => __( 'French', 'wps-ai-chatgpt' ),
				'English' => __( 'English', 'wps-ai-chatgpt' ),
				// Ajoutez d'autres langues si nécessaire
			),
		) );

		$wp_customize->add_setting( 'wpb_chatbot_ai_widget_gender', array(
			'default'           => 'female',
			'sanitize_callback' => 'sanitize_text_field',
		) );

		$wp_customize->add_control( 'wpb_chatbot_ai_widget_gender', array(
			'label'    => __( 'Gender of your Chatbot', 'wps-ai-chatgpt' ),
			'section'  => 'wpb_chatbot_ai_section',
			'settings' => 'wpb_chatbot_ai_widget_gender',
			'type'     => 'radio',
			'choices'  => array(
				'female'       => __( 'Female', 'wps-ai-chatgpt' ),
				'male'         => __( 'Male', 'wps-ai-chatgpt' ),
				'not_gendered' => __( 'Not genred', 'wps-ai-chatgpt' ),
			)
		) );

		$wp_customize->add_control( new \WP_Customize_Control( $wp_customize, 'wpb_chatbot_ai_widget_position', array(
			'label'    => __( 'Position of your Chatbot ?', 'wps-ai-chatgpt' ),
			'section'  => 'wpb_chatbot_ai_section',
			'settings' => 'wpb_chatbot_ai_widget_position',
			'type'     => 'radio',
			'choices'  => array(
				'right' => __( 'Right', 'wps-ai-chatgpt' ),
				'left'  => __( 'Left', 'wps-ai-chatgpt' ),
			)
		) ) );

		$wp_customize->add_control( 'wpb_chatbot_ai_widget_max_tokens', array(
			'label'       => __( 'Max Tokens', 'wps-ai-chatgpt' ),
			'description' => __( 'The number of tokens processed in a single API request depends on the length of the input and output text. Typically, a token is roughly equivalent to 4 characters or 0.75/word.', 'wps-ai-chatgpt' ),
			'type'        => 'number',
			'section'     => 'wpb_chatbot_ai_section',
			'input_attrs' => array(
				'min'  => 16,
				'max'  => 4096,
				'step' => 10,
			),
		) );

		$wp_customize->add_control( 'wpb_chatbot_ai_widget_temperature', array(
			'label'       => __( 'Temperature', 'wps-ai-chatgpt' ),
			'description' => __( 'At lower temperatures, GPT will tend to choose words with a higher probability of occurrence. On the other hand, higher temperatures will produce a greater variety of responses.', 'wps-ai-chatgpt' ),
			'type'        => 'range',
			'section'     => 'wpb_chatbot_ai_section',
			'input_attrs' => array(
				'min'  => 0,
				'max'  => 2,
				'step' => 0.1,
			),
		) );

		$wp_customize->add_control( 'wpb_chatbot_ai_widget_max_presence_penalty', array(
			'label'       => __( 'Max presence penalty', 'wps-ai-chatgpt' ),
			'description' => __( 'In general, the default value of Presence Penalty is 0 and it is used when you want to generate text consistent with the input prompt, using words present in the input.', 'wps-ai-chatgpt' ),
			'type'        => 'range',
			'section'     => 'wpb_chatbot_ai_section',
			'input_attrs' => array(
				'min'  => - 2,
				'max'  => 2,
				'step' => 0.1,
			),
		) );

		$wp_customize->add_control( 'wpb_chatbot_ai_widget_max_frequency_penalty', array(
			'label'       => __( 'Max frequence penalty', 'wps-ai-chatgpt' ),
			'description' => __( 'Positive values ​​will reduce the likelihood of the pattern repeating the same line verbatim. If the goal is to significantly remove repetition, the coefficients can be increased up to 2.', 'wps-ai-chatgpt' ),
			'type'        => 'range',
			'section'     => 'wpb_chatbot_ai_section',
			'input_attrs' => array(
				'min'  => - 2,
				'max'  => 2,
				'step' => 0.1,
			),
		) );

		$wp_customize->add_control( 'wpb_chatbot_ai_widget_bestof', array(
			'label'       => __( 'Best_of' ),
			'type'        => 'number',
			'section'     => 'wpb_chatbot_ai_section',
			'input_attrs' => array(
				'min'  => 1,
				'max'  => 10,
				'step' => 1,
			),
		) );

		$nombreAleatoire = rand( 1, 2 );

		if ( 1 == $nombreAleatoire ) {
			$wp_customize->add_setting( 'wpb_chatbot_ai_widget_pub_bottom_first' );
			$wp_customize->add_control( new \WP_Pub_WPServeur_Customize_Control( $wp_customize, 'wpb_chatbot_ai_widget_pub_bottom_first', array(
				'label'    => __( 'Pub bottom first', 'wps-ai-chatgpt' ),
				'section'  => 'wpb_chatbot_ai_section',
				'settings' => 'wpb_chatbot_ai_widget_pub_bottom_first'
			) ) );
		} else {
			$wp_customize->add_setting( 'wpb_chatbot_ai_widget_pub_bottom_second' );
			$wp_customize->add_control( new \WP_Pub_Nuxit_Customize_Control( $wp_customize, 'wpb_chatbot_ai_widget_pub_bottom_second', array(
				'label'    => __( 'Pub bottom second', 'wps-ai-chatgpt' ),
				'section'  => 'wpb_chatbot_ai_section',
				'settings' => 'wpb_chatbot_ai_widget_pub_bottom_second'
			) ) );
		}


	}

	public static function admin_enqueue_scripts() {
		wp_enqueue_style( 'wps-ai-chatgpt-style', WPS_CHATBOT_AI_URL . 'assets/css/style.css', array(), WPS_CHATBOT_AI_VERSION );

		wp_enqueue_script( 'wps-ai-chatgpt-script', WPS_CHATBOT_AI_URL . 'assets/js/script.js', array( 'jquery' ), WPS_CHATBOT_AI_VERSION, true );

		$api_key = get_theme_mod( 'wpb_chatbot_ai_widget_api_key' );
		wp_localize_script(
			'wps-ai-chatgpt-script',
			'data_chatbot',
			array(
				'apikey' => $api_key,
				'url'    => admin_url( 'admin-ajax.php' ),
				'nonce'  => wp_create_nonce( 'save-chat-nonce' ),
			)
		);

		wp_localize_script( 'wps-ai-chatgpt-script', 'AysChatGPTChatSettings', array(
			'chatTemprature'       => get_theme_mod( 'wpb_chatbot_ai_widget_temperature' ),
			'chatMaxTokents'       => get_theme_mod( 'wpb_chatbot_ai_widget_max_tokens' ),
			'chatFrequencyPenalty' => get_theme_mod( 'wpb_chatbot_ai_widget_max_frequency_penalty' ),
			'chatPresencePenalty'  => get_theme_mod( 'wpb_chatbot_ai_widget_max_presence_penalty' ),
			'chatBestOf'           => get_theme_mod( 'wpb_chatbot_ai_widget_bestof', 1 ),
			'chatboxPosition'      => get_theme_mod( 'wpb_chatbot_ai_widget_position' ),
			'chatboxLanguage'      => get_theme_mod( 'wpb_chatbot_ai_widget_language', 'french' ),
			'chatboxPersonality'   => get_theme_mod( 'wpb_chatbot_ai_widget_personality', 'Personal' ),
			'chatboxGender'        => get_theme_mod( 'wpb_chatbot_ai_widget_gender', 'female' ),
			'chatboxFunctionJob'   => get_theme_mod( 'wpb_chatbot_ai_widget_function_job' ),
			'ip_client'            => $_SERVER['REMOTE_ADDR']
		) );
	}

	public static function shortcode_chatbot_wordpress() {
		$api_key = get_theme_mod( 'wpb_chatbot_ai_widget_api_key' );
		if ( isset( $api_key ) && $api_key != '' ) :
			//$this->set_global_settings_options();

			$widget_icon = ( get_theme_mod( 'wpb_chatbot_ai_widget_icon' ) ? get_theme_mod( 'wpb_chatbot_ai_widget_icon' ) : ( WPS_CHATBOT_AI_URL ) . "admin/images/icons/chatgpt-icon.png" );

			ob_start();
			?>
            <div class="ays-assistant-chatbox" style="display: none;"
                 colmode="<?php echo ( get_theme_mod( 'wpb_chatbot_ai_widget_darkmode' ) === "1" ) ? esc_attr( 'dark' ) : esc_attr( "light" ); ?>">
                <div class="ays-assistant-chatbox-closed-view"> <!-- closed logo -->
                    <div class="ays-assistant-closed-icon-container">
                        <img class="ays-assistant-chatbox-logo-image"
                             src="<?php echo esc_attr( $widget_icon ); ?>"
                             alt="ChatGPT icon">
                    </div>
                </div>
                <div class="ays-assistant-chatbox-maximized-bg" style="display: none;"></div>
                <div class="ays-assistant-chatbox-main-container" style="display: none;">
                    <div class="ays-assistant-chatbox-main-chat-box">
                        <div class="ays-assistant-chatbox-header-row"> <!-- header row -->
                            <!-- <p class="ays-assistant-chatbox-header-text">ChatGPT Assistant</p> -->
                            <div class="ays-assistant-header-row-logo-row">
                                <div class="ays-assistant-header-row-logo">
                                    <img class="ays-assistant-header-row-logo-image"
                                         src="<?php echo esc_attr( $widget_icon ); ?>"
                                         alt="ChatGPT icon">
                                </div>
                                <p class="ays-assistant-chatbox-header-text"><?php echo __( "AI Assistant", "ays-chatgpt-assistant" ); ?></p>
                            </div>
                            <div class="ays-assistant-chatbox-logo">
                                <img src="<?php echo esc_attr( WPS_CHATBOT_AI_URL ) ?>/admin/images/icons/maximize.svg"
                                     alt="Maximize" class="ays-assistant-chatbox-resize-bttn">
                                <img src="<?php echo esc_attr( WPS_CHATBOT_AI_URL ) ?>/admin/images/icons/close-button.svg"
                                     alt="Close" class="ays-assistant-chatbox-close-bttn">
                            </div>
                        </div>
                        <div class="ays-assistant-chatbox-messages-box"> <!-- messages container -->
                            <div class="ays-assistant-chatbox-loading-box" style="display: none;"> <!-- loader -->
                                <div class="ays-assistant-chatbox-loader-ball-2">
                                    <div></div>
                                    <div></div>
                                    <div></div>
                                </div>
                            </div>
                        </div>
                        <div class="ays-assistant-chatbox-input-box"> <!-- prompt part -->
                            <input class="ays-assistant-chatbox-prompt-input" type="text"
                                   name="ays_assistant_chatbox_prompt" id="ays-assistant-chatbox-prompt"
                                   placeholder="Entrez votre message">
                            <button class="ays-assistant-chatbox-send-button" disabled>
                                <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512" fill="#f8f8f8" width="18"
                                     height="18">
                                    <path d="M498.1 5.6c10.1 7 15.4 19.1 13.5 31.2l-64 416c-1.5 9.7-7.4 18.2-16 23s-18.9 5.4-28 1.6L284 427.7l-68.5 74.1c-8.9 9.7-22.9 12.9-35.2 8.1S160 493.2 160 480V396.4c0-4 1.5-7.8 4.2-10.7L331.8 202.8c5.8-6.3 5.6-16-.4-22s-15.7-6.4-22-.7L106 360.8 17.7 316.6C7.1 311.3 .3 300.7 0 288.9s5.9-22.8 16.1-28.7l448-256c10.7-6.1 23.9-5.5 34 1.4z"/>
                                </svg>
                            </button>
                        </div>
                    </div>
                </div>
            </div>
			<?php //echo ChatGPT_assistant_Data::get_chatbot_styles($this->chatbot_global_styles);
			?>

            <style>

                div.ays-assistant-chatbox div.ays-assistant-chatbox-main-container {
                    right: 0;
                }

                div.ays-assistant-chatbox div.ays-assistant-chatbox-closed-view {
                <?php echo get_theme_mod('wpb_chatbot_ai_widget_position'); ?>: 20 px;
                }

                div.ays-assistant-chatbox-main-container div.ays-assistant-chatbox-header-row,
                div.ays-assistant-chatbox-main-container button.ays-assistant-chatbox-send-button {
                    background-color: <?php echo get_theme_mod('wpb_chatbot_ai_widget_color'); //#4e426d ?>
                }

                <?php if( get_theme_mod( 'wpb_chatbot_ai_widget_darkmode' ) !== "1" ) : ?>
                .ays-assistant-chatbox .ays-assistant-chatbox-messages-box {
                    background-color: <?php echo get_theme_mod('wpb_chatbot_ai_widget_background_color'); //#ffffff ?>
                }

                div.ays-assistant-chatbox-main-container button.ays-assistant-chatbox-send-button:disabled {
                    background-color: #4e426d2b;
                }

                div.ays-assistant-chatbox-main-container div.ays-assistant-chatbox-messages-box div.ays-assistant-chatbox-ai-message-box,
                div.ays-assistant-chatbox-main-container div.ays-assistant-chatbox-messages-box div.ays-assistant-chatbox-loading-box {
                    background-color: <?php echo get_theme_mod('wpb_chatbot_ai_widget_response_background_color'); //#d3d3d3 ?>
                }

                div.ays-assistant-chatbox-main-container div.ays-assistant-chatbox-messages-box div.ays-assistant-chatbox-user-message-box {
                    background-color: <?php echo get_theme_mod('wpb_chatbot_ai_widget_user_message_background_color'); //#4e426d ?>
                }

                <?php endif; ?>
            </style>

		<?php
		endif;

		$content = ob_get_clean();

		return $content;
	}

	public static function wps_chatgpt_assistant_shortcodes_show_all() {
		//var_dump(get_theme_mod( 'wpb_chatbot_ai_widget_show_chat_front_end' ));die;
		if ( get_theme_mod( 'wpb_chatbot_ai_widget_show_chat_front_end' ) != "true" ) {
			return false;
		}
		echo do_shortcode( '[wps_chatgpt_assistant]' );
	}

	public static function wps_chatbot_ai_ajax_save_chat_action() {
		if ( ! wp_verify_nonce( $_POST['nonce'], 'save-chat-nonce' ) ) {
			return;
		}

		$answer   = $_POST['answer'];
		$response = $_POST['response'];
		$ip       = $_POST['ip'];

		if ( empty( $answer ) || empty( $response ) ) {
			return false;
		}

		global $wpdb;
		$tablename = $wpdb->prefix . 'wps_chatbot_ai';

		$wpdb->insert( $tablename, array(
			'answer'   => $answer,
			'response' => $response,
			'ip'       => $ip,
		), array( '%s', '%s', '%s' )
		);

		echo wp_send_json( array(
			'success' => true
		) );
		wp_die();
	}

	/**
	 * Add menu and sub pages
	 *
	 * @return void
	 * @since 1.0
	 * @see admin_menu
	 *
	 */
	public static function add_plugin_menu() {
		$menu_icon = '';

		add_menu_page( 'WPS AI ChatGPT', 'WPS AI ChatGPT', 'manage_options', 'wps-ai-chatgpt-conversation', array(
			__CLASS__,
			'wps_chatbot_ai_plugin_conversation_page'
		), $menu_icon );

		remove_submenu_page( 'edit.php', 'edit.php' ); // Tous les articles
		remove_submenu_page( 'edit.php', 'post-new.php' ); // Ajouter un article
		remove_submenu_page( 'edit.php', 'edit-tags.php?taxonomy=category' ); // Catégories
		remove_submenu_page( 'edit.php', 'edit-tags.php?taxonomy=post_tag' ); // Mots-clés

		add_submenu_page( 'edit.php', 'Tous les articles', 'Tous les articles', 'manage_options', 'edit.php', '', 5 );
		add_submenu_page( 'edit.php', 'Ajouter un article', 'Ajouter un article', 'manage_options', 'post-new.php?post_type=post', '', 10 );
		add_submenu_page(
			'edit.php',
			'Générer',
			'Générer',
			'manage_options',
			'post-new.php#chatgpt_meta_box',
			'',
			15
		);
		add_submenu_page( 'edit.php', 'Catégories', 'Catégories', 'manage_options', 'edit-tags.php?taxonomy=category', '', 20 );
		add_submenu_page( 'edit.php', 'Mots-clés', 'Mots-clés', 'manage_options', 'edit-tags.php?taxonomy=post_tag', '', 30 );
	}


	/**
	 * Page settings
	 *
	 * @return void
	 * @throws \Exception
	 * @since 1.0
	 *
	 */
	public static function wps_chatbot_ai_plugin_conversation_page() {
		global $wpdb;
		$chatbot_table_name = $wpdb->prefix . 'wps_chatbot_ai';

		$results = $wpdb->get_results(
		//$wpdb->prepare("
			"SELECT ip, DATE_FORMAT(time, '%Y-%m-%d') AS date, COUNT(*) AS total_count, GROUP_CONCAT(answer SEPARATOR '|||') AS answers, GROUP_CONCAT(response SEPARATOR '|||') AS responses
            FROM $chatbot_table_name
            GROUP BY ip, date;
			"
		//)
		);

		echo '<h3>Historique des conversations</h3>'; ?>
        <div class="wps-autopromo" id="plugin-filter">
			<?php //include( WPS_CHATBOT_AI_DIR . '/blocks/pub-wpserveur.php' ); ?>
			<?php include( WPS_CHATBOT_AI_DIR . '/blocks/pub-ai-wpserveur.php' ); ?>
			<?php //include( WPS_CHATBOT_AI_DIR . '/blocks/pub-nuxit.php' ); ?>
        </div>
        <hr>
		<?php
		echo '<table class="wp-table">';
		echo '<tr><th>Date</th><th>IP</th><th>Nombre d\'échange</th><th>Conversation</th></tr>';

		// Parcourir les résultats
		foreach ( $results as $result ) {

			$result = (array) $result;

			$ip   = $result['ip'];
			$date = $result['date'];

			// Diviser les réponses et les réponses en utilisant le délimiteur |||
			$answers   = explode( '|||', $result['answers'] );
			$responses = explode( '|||', $result['responses'] );

			// Reconstituer la conversation answer/response
			$conversation = '';
			for ( $i = 0; $i < count( $answers ); $i ++ ) {
				$answer       = $answers[ $i ];
				$response     = $responses[ $i ];
				$conversation .= '- ' . stripslashes( $answer ) . ': ' . stripslashes( $response ) . "\n" . "<br>";
			}

			// Afficher la conversation
			/*echo "IP: $ip\n";
			echo "Date: $date\n";
			echo "Conversation:\n$conversation\n";
			echo "---------------------------------\n";*/

			echo '<tr>';
			echo '<td>' . $date . '</td>';
			echo '<td>' . $ip . '</td>';
			echo '<td>' . $result['total_count'] . '</td>';
			echo '<td>' . $conversation . '</td>';
			echo '</tr>';
		}

		echo '</table>';

		ob_start() ?>

        <style>
            /* Styles pour le tableau */
            .wp-table {
                border-collapse: collapse;
                width: 100%;
            }

            .wp-table th,
            .wp-table td {
                border: 1px solid #ddd;
                padding: 8px;
                text-align: left;
            }

            .wp-table th {
                background-color: #f7f7f7;
                font-weight: bold;
            }

            .wp-table tr:nth-child(even) {
                background-color: #f2f2f2;
            }

            .wp-table tr:hover {
                background-color: #ddd;
            }
        </style>
		<?php
		return ob_get_contents();

	}
}
